## ProVerif

ProVerif is an automatic verification tool for cryptographic protocols.
All the relevant information about ProVerif are available at: [https://proverif.inria.fr/](https://proverif.inria.fr/).

**Version:** the ProVerif files have been executed using the master branch of the official ProVerif repository [git](https://gitlab.inria.fr/bblanche/proverif).
They can also be executed using the last official release, i.e. ProVerif v.2.04.

## Files

This folder contains 3 different files:
- `beleniosCaI.pv`: allows to prove verifiability
- `beleniosCaI-priv.pv`: allows to prove vote secrecy
- `beleniosCaI-priv-lemma.pv`: allows to prove the lemma for vote secrecy

#### Verifiability
The `beleniosCaI.pv` file encodes the 4 security properties mentioned in the submitted paper:
cast-as-intended, no clash, recorded-as-cast, recorded-as-cast (strong).
Following the approach developed in [1], the recorded-as-cast properties
are duplicated depending whether the voter is identified by their id (i.e. the server
is honest) or by their credential (i.e. the registrar is honest).
Our ProVerif file handles both cases.

To analyse BeleniosCaI under different trust assumptions, booleans at lines l.14-16 can
be modified.
*Warning:* it is important to not forget to define the channels `c_mail()` and
`c_server()` as public channels (i.e. remove the attribute `[private]`) when the
voting server is malicious (`c_mail()` and `c_server()`) or when the voting device is
compromised (`c_server()` only).

#### Vote secrecy
Following the approach developed in [2], two models are needed to prove the vote secrecy
property: `beleniosCaI-priv.pv` proves the main equivalence and `beleniosCaI-priv-lemma.pv`
the additional lemma (i.e. relation preservation).
A detailed description of the approach and its soundness is provided in [2].


[1] V. Cortier, A. Filipiak, and J. Lallemand. *BeleniosVS: Secrecy and verifiability against a corrupted voting device.* In 32nd IEEE Computer Security Foundations Symposium (CSF’19), 2019.<p>
[2] M. Bougon, H. Chabanne, V. Cortier, A. Debant, E. Dottax, J. Dreier, P. Gaudry, and M. Turuani. *Themis: an On-Site Voting System with Systematic Cast-as- intended Verification and Partial Accountability.* In 25th ACM Conference on Computer and Communications Security (CCS’22), 2022.
